==> model-1.2-sources.jar: org/ow2/weblab/core/model/Audio.java <==

package org.ow2.weblab.core.model;

import java.io.Serializable;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlType;


/**
 * An audio unit describes audio content out of
 * 				media document. It does not have any particular attribute but only
 * 				allow describing the structure. As a resource it can be annotated to
 * 				describe the audio content. It can also be described using low level
 * 				descriptors. The original content may be in content field or a
 * 				reference using an annotation should be made to the content. Data
 * 				Exchange Model for WebLab platform provided by CASSIDIAN - Version 1.2 -
 * 				2010/08
 * 
 * <p>Java class for Audio complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="Audio">
 *   &lt;complexContent>
 *     &lt;extension base="{http://weblab.ow2.org/core/1.2/model#}MediaUnit">
 *       &lt;sequence>
 *         &lt;element name="content" type="{http://www.w3.org/2001/XMLSchema}base64Binary" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "Audio", propOrder = {
    "content"
})
public class Audio
    extends MediaUnit
    implements Serializable
{

    private final static long serialVersionUID = 12L;
    protected byte[] content;

    /**
     * Gets the value of the content property.
     * 
     * @return
     *     possible object is
     *     byte[]
     */
    public byte[] getContent() {
        return content;
    }

    /**
     * Sets the value of the content property.
     * 
     * @param value
     *     allowed object is
     *     byte[]
     */
    public void setContent(byte[] value) {
        this.content = ((byte[]) value);
    }

    public boolean isSetContent() {
        return (this.content!= null);
    }

}

==> model-1.2.2-sources.jar: org/ow2/weblab/core/model/Audio.java <==

package org.ow2.weblab.core.model;

import java.io.Serializable;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlType;


/**
 * An Audio unit describes audio content out of media document. It allows describing the structure and may contain the bytes of the 
 *             Audio part (note that it's not recommended with big content). As a resource it can be annotated to describe the audio content. 
 *             It can also be described using low level descriptors. The original content may be in content field or a reference using an annotation 
 *             should be made to the content.
 * 
 * 				Data Exchange Model for WebLab platform provided by CASSIDIAN Version 1.2.1 - 2011/05
 * 
 * <p>Java class for Audio complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="Audio">
 *   &lt;complexContent>
 *     &lt;extension base="{http://weblab.ow2.org/core/1.2/model#}MediaUnit">
 *       &lt;sequence>
 *         &lt;element name="content" type="{http://www.w3.org/2001/XMLSchema}base64Binary" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "Audio", propOrder = {
    "content"
})
public class Audio
    extends MediaUnit
    implements Serializable
{

    private final static long serialVersionUID = 121L;
    protected byte[] content;

    /**
     * Gets the value of the content property.
     * 
     * @return
     *     possible object is
     *     byte[]
     */
    public byte[] getContent() {
        return content;
    }

    /**
     * Sets the value of the content property.
     * 
     * @param value
     *     allowed object is
     *     byte[]
     */
    public void setContent(byte[] value) {
        this.content = ((byte[]) value);
    }

    public boolean isSetContent() {
        return (this.content!= null);
    }

}
